@@ -24,12 +24,6 @@ EXAMPLES_DEPS="\
 	libprotobuf-c-dev \
 	valgrind"
 
-TOOLS_DEPS="\
-	python3-jinja2"
-
-TESTS_DEPS="\
-	pylint"
-
 RPMA_DEPS="\
 	cmake \
 	curl \
@@ -66,6 +60,4 @@ sudo apt-get update --allow-unauthenticated
 sudo apt-get install --assume-yes --no-install-recommends --allow-unauthenticated \
 	$BASE_DEPS \
 	$EXAMPLES_DEPS \
-	$TOOLS_DEPS \
-	$TESTS_DEPS \
 	$RPMA_DEPS
